@@ -17,7 +17,7 @@ use Text::Abbrev();
 use Exporter ();
 our @ISA = qw{ Exporter };
 
-our $VERSION = '0.009_01';
+our $VERSION = '0.001';
 
 our @EXPORT_OK = qw{
     __am_or_pm
@@ -26,46 +26,29 @@ our @EXPORT_OK = qw{
     __day_of_week
     __format
     __is_leap_year
-    __holiday_abbr __holiday_name __holiday_narrow
-    __holiday_name_to_number
+    __holiday_name __holiday_name_to_number __holiday_abbr
     __month_name __month_name_to_number __month_abbr
     __on_date __on_date_accented
     __quarter __quarter_name __quarter_abbr
     __rata_die_to_year_day
-    __trad_weekday_abbr __trad_weekday_name __trad_weekday_narrow
+    __trad_weekday_name __trad_weekday_abbr
     __valid_date_class
-    __weekday_abbr __weekday_name __weekday_narrow
+    __weekday_name __weekday_abbr
     __week_of_year
     __year_day_to_rata_die
-    DAY_OF_YEAR_MIDYEARS_DAY
-    DAY_OF_YEAR_OVERLITHE
     GREGORIAN_RATA_DIE_TO_SHIRE
-    HOLIDAY_2_YULE
-    HOLIDAY_1_LITHE
-    HOLIDAY_MIDYEARS_DAY
-    HOLIDAY_OVERLITHE
-    HOLIDAY_2_LITHE
-    HOLIDAY_1_YULE
 };
 our %EXPORT_TAGS = (
-    all		=> \@EXPORT_OK,
-    subs	=> [ grep { m/ \A __ /smx } @EXPORT_OK ],
-    consts	=> [ grep { m/ \A [[:upper:]] /smx } @EXPORT_OK ],
+    all	=> \@EXPORT_OK,
 );
 
 use constant ARRAY_REF	=> ref [];
 use constant CODE_REF	=> ref sub {};
 use constant HASH_REF	=> ref {};
 
-use constant DAY_OF_YEAR_MIDYEARS_DAY	=> 183;
-use constant DAY_OF_YEAR_OVERLITHE	=> 184;
-
-use constant HOLIDAY_2_YULE		=> 1;
-use constant HOLIDAY_1_LITHE		=> 2;
-use constant HOLIDAY_MIDYEARS_DAY	=> 3;
-use constant HOLIDAY_OVERLITHE		=> 4;
-use constant HOLIDAY_2_LITHE		=> 5;
-use constant HOLIDAY_1_YULE		=> 6;
+use constant MIDYEAR_DAY_OF_YEAR	=> 183;
+use constant OVERLITHE_DAY_NUMBER	=> 4;
+use constant OVERLITHE_DAY_OF_YEAR	=> 184;
 
 # See the documentation below for where the value came from.
 
@@ -98,7 +81,7 @@ use constant GREGORIAN_RATA_DIE_TO_SHIRE	=> 1995694;
 }
 
 {
-    my @holiday_day = ( undef, 1, 182, 183, DAY_OF_YEAR_OVERLITHE, 185, 366 );
+    my @holiday_day = ( undef, 1, 182, 183, OVERLITHE_DAY_OF_YEAR, 185, 366 );
     my @month_zero = ( undef, 1, 31, 61, 91, 121, 151, 185, 215, 245,
 	275, 305, 335 );
 
@@ -112,9 +95,9 @@ use constant GREGORIAN_RATA_DIE_TO_SHIRE	=> 1995694;
 
 	unless ( __is_leap_year( $year ) ) {
 	    not $month
-		and HOLIDAY_OVERLITHE == $day
+		and OVERLITHE_DAY_NUMBER == $day
 		and Carp::croak( 'Overlithe only occurs in a leap year' );
-	    $yd >= DAY_OF_YEAR_OVERLITHE
+	    $yd >= OVERLITHE_DAY_OF_YEAR
 		and --$yd;
 	}
 	return $yd;
@@ -126,7 +109,7 @@ use constant GREGORIAN_RATA_DIE_TO_SHIRE	=> 1995694;
 	my ( $year, $yd ) = $validate_doy2d->( @_ );
 
 	unless ( __is_leap_year( $year ) ) {
-	    $yd >= DAY_OF_YEAR_OVERLITHE
+	    $yd >= OVERLITHE_DAY_OF_YEAR
 		and $yd++;
 	}
 	$yd > 0
@@ -224,18 +207,12 @@ sub _fmt_cond {
 		    return _fmt_number_02( @_[ 0, 1 ],
 			$_[0]->__fmt_shire_day() );
 		},
-	Ea	=> sub { $_[0]->__fmt_shire_traditional() ?
-		    __trad_weekday_narrow( $_[0]->__fmt_shire_day_of_week() ) :
-		    __weekday_narrow( $_[0]->__fmt_shire_day_of_week() );
-		},
 	Ed	=> \&_fmt_on_date,
 	EE	=> sub { __holiday_name( $_[0]->__fmt_shire_month() ? 0 :
 		$_[0]->__fmt_shire_day() ) },
 	Ee	=> sub { __holiday_abbr( $_[0]->__fmt_shire_month() ? 0 :
 		$_[0]->__fmt_shire_day() ) },
 	En	=> sub { $_[1]{prefix_new_line_unless_empty}++; '' },
-	Eo	=> sub { __holiday_narrow( $_[0]->__fmt_shire_month() ? 0 :
-		$_[0]->__fmt_shire_day() ) },
 	Ex	=> sub { __format( $_[0],
 		    '%{{%A %-e %B %Y||%A %EE %Y||%EE %Y}}' ) },
 	e	=> sub {
@@ -438,35 +415,35 @@ sub _fmt_on_date {
     return "$pfx$on_date";
 }
 
-{
-    my @name = ( '',
-	'2Yu', '1Li', 'Myd', 'Oli', '2Li', '1Yu',
-    );
-
-    sub __holiday_abbr {
-	return _lookup( $_[0], \@name );
-    }
-}
-
 {
     my @name = ( '',
 	'2 Yule', '1 Lithe', q<Midyear's day>, 'Overlithe', '2 Lithe',
 	'1 Yule',
     );
 
+    my $validate_name = _make_validator( qw{ UInt|Undef } );
+
     sub __holiday_name {
-	return _lookup( $_[0], \@name );
+	my ( $holiday ) = $validate_name->( @_ );
+	defined $holiday
+	    or return [ @name ];
+	return $name[ $holiday || 0 ];
     }
 
 }
 
 {
     my @name = ( '',
-	'2Y', '1L', 'My', 'Ol', '2L', '1Y',
+	'2Yu', '1Li', 'Myd', 'Oli', '2Li', '1Yu',
     );
 
-    sub __holiday_narrow {
-	return _lookup( $_[0], \@name );
+    my $validate = _make_validator( qw{ UInt|Undef } );
+
+    sub __holiday_abbr {
+	my ( $holiday ) = $validate->( @_ );
+	defined $holiday
+	    or return [ @name ];
+	return $name[ $holiday || 0 ];
     }
 }
 
@@ -557,8 +534,8 @@ sub _fmt_on_date {
 
     $on_date[1][8]   = "The Company of the Ring reaches Hollin, 1419.\n";
     $on_date[1][13]  = "The Company of the Ring reaches the West-gate of Moria at nightfall, 1419.\n";
-    $on_date[1][14]  = "The Company of the Ring spends the night in Moria Hall 21, 1419.\n";
-    $on_date[1][15]  = "The Bridge of Khazad-dum, and fall of Gandalf, 1419.\n";
+    $on_date[1][14]  = "The Company of the Ring spends the night in Moria hall 21, 1419.\n";
+    $on_date[1][15]  = "The Bridge of Khazad-dum, and the fall of Gandalf, 1419.\n";
     $on_date[1][17]  = "The Company of the Ring comes to Caras Galadhon at evening, 1419.\n";
     $on_date[1][23]  = "Gandalf pursues the Balrog to the peak of Zirakzigil, 1419.\n";
     $on_date[1][25]  = "Gandalf casts down the Balrog, and passes away.\n" .
@@ -579,7 +556,7 @@ sub _fmt_on_date {
     $on_date[2][27]  = "Aragorn reaches the west-cliff at sunrise, 1419.\n" .
 		       "Eomer sets out from Eastfold against Theoden's orders to pursue the Orcs, 1419.\n";
     $on_date[2][28]  = "Eomer overtakes the Orcs just outside of Fangorn Forest, 1419.\n";
-    $on_date[2][29]  = "Meriadoc and Pippin escape and meet Treebeard, 1419.\n" .
+    $on_date[2][29]  = "Meriodoc and Pippin escape and meet Treebeard, 1419.\n" .
 		       "The Rohirrim attack at sunrise and destroy the Orcs, 1419.\n" .
 		       "Frodo descends from the Emyn Muil and meets Gollum, 1419.\n" .
 		       "Faramir sees the funeral boat of Boromir, 1419.\n";
@@ -638,8 +615,8 @@ sub _fmt_on_date {
     $on_date[3][27]  = "Bard II and Thorin III Stonehelm drive the enemy from Dale, 1419.\n";
     $on_date[3][28]  = "Celeborn crosses the Anduin and begins destruction of Dol Guldur, 1419.\n";
 
-    $on_date[4][6]   = "The mallorn tree flowers in the Party Field, 1420.\n";
-    $on_date[4][8]   = "Ring bearers are honored on the Field of Cormallen, 1419.\n";
+    $on_date[4][6]   = "The mallorn tree flowers in the party field, 1420.\n";
+    $on_date[4][8]   = "Ring bearers are honored on the fields of Cormallen, 1419.\n";
     $on_date[4][12]  = "Gandalf arrives in Hobbiton, 1418\n";
 
     $on_date[5][1]   = "Crowning of King Elessar, 1419.\n" .
@@ -735,7 +712,6 @@ sub _fmt_on_date {
 			$day =~ s/ \b Nazgul \b /Nazg${u_circ}l/smxgo;
 			$day =~ s/ \b Theoden \b /Th${e_acute}oden/smxgo;
 			$day =~ s/ \b Theodred \b /Th${e_acute}odred/smxgo;
-			$day =~ s/ \b Udun \b /Ud${u_circ}n/smxgo;
 		    }
 		    push @{ $on_date_accented[-1] }, $day;
 		}
@@ -809,24 +785,22 @@ sub _fmt_on_date {
     my @name = ( '', 'Sterrendei', 'Sunnendei', 'Monendei',
 	'Trewesdei', 'Hevenesdei', 'Meresdei', 'Highdei' );
 
+    my $validate = _make_validator( qw{ UInt } );
+
     sub __trad_weekday_name {
-	return _lookup( $_[0], \@name );
+	my ( $weekday ) = $validate->( @_ );
+	return $name[ $weekday ];
     }
 }
 
 {
     my @name = ( '', 'Ste', 'Sun', 'Mon', 'Tre', 'Hev', 'Mer', 'Hig' );
 
+    my $validate = _make_validator( qw{ UInt } );
+
     sub __trad_weekday_abbr {
-	return _lookup( $_[0], \@name );
-    }
-}
-
-{
-    my @name = ( '', 'St', 'Su', 'Mo', 'Tr', 'He', 'Me', 'Hi' );
-
-    sub __trad_weekday_narrow {
-	return _lookup( $_[0], \@name );
+	my ( $weekday ) = $validate->( @_ );
+	return $name[ $weekday ];
     }
 }
 
@@ -850,24 +824,22 @@ sub _fmt_on_date {
     my @name = ( '', 'Sterday', 'Sunday', 'Monday', 'Trewsday',
 	'Hevensday', 'Mersday', 'Highday' );
 
+    my $validate = _make_validator( qw{ UInt } );
+
     sub __weekday_name {
-	return _lookup( $_[0], \@name );
+	my ( $weekday ) = $validate->( @_ );
+	return $name[ $weekday ];
     }
 }
 
 {
     my @name = ( '', 'Ste', 'Sun', 'Mon', 'Tre', 'Hev', 'Mer', 'Hig' );
 
+    my $validate = _make_validator( qw{ UInt } );
+
     sub __weekday_abbr {
-	return _lookup( $_[0], \@name );
-    }
-}
-
-{
-    my @name = ( '', 'St', 'Su', 'Mo', 'Tr', 'He', 'Me', 'Hi' );
-
-    sub __weekday_narrow {
-	return _lookup( $_[0], \@name );
+	my ( $weekday ) = $validate->( @_ );
+	return $name[ $weekday ];
     }
 }
 
@@ -1012,10 +984,6 @@ sub _make_lookup_hash {
 	# validators in-line, above, and %type_def needs to be populated
 	# before that happens.
 	%type_def = (
-	    # An array reference
-	    Array	=> sub {
-		ARRAY_REF eq ref $_ ? 0 : 'an ARRAY reference'
-	    },
 	    # A hash reference
 	    Hash	=> sub { HASH_REF eq ref $_ ? 0 : 'a HASH reference' },
 	    # An integer, optionally signed
@@ -1123,23 +1091,6 @@ sub _normalize_for_lookup {
     }
 }
 
-{
-    my $validate;
-
-    BEGIN {
-	$validate = _make_validator( qw{ UInt|Undef Array } );
-    }
-
-    sub _lookup {
-	my ( $inx, $tbl ) = $validate->( @_ );
-	defined $inx
-	    and return $tbl->[ $inx ];
-	__PACKAGE__ eq caller
-	    or Carp::croak( 'Index not defined' );
-	return $tbl;
-    }
-}
-
 1;
 
 __END__
@@ -1189,20 +1140,6 @@ as follows:
 
 =back
 
-This module is subroutine-based. Nothing is exported by default, but
-everything public can be exported by name. In addition the following
-export tags exist:
-
-=over
-
-=item C<:all> - export everything;
-
-=item C<:consts> - export all manifest constants;
-
-=item C<:subs> - export all subroutines.
-
-=back
-
 =head1 SUBROUTINES
 
 This class supports the following public subroutines. Anything
@@ -1213,7 +1150,7 @@ concerned, they will be package-private for the purposes of any code
 that uses this package.
 
 All of the following are exportable to your name space, but none are
-exported by default. They can all be exported using export tag C<:subs>.
+exported by default.
 
 =head2 __am_or_pm
 
@@ -1369,7 +1306,7 @@ and month, and the weekday name is omitted if the holiday is part of no
 week. So (assuming times for all events):
 
  Sun 25 Ret 1419  3:00:00 PM # Ring destroyed
- Myd 1419 12:00:00 PM        # Wedding of Aragorn and Arwen
+ Myd 1419 12:00:OO PM        # Wedding of Aragorn and Arwen
 
 =item %D
 
@@ -1383,11 +1320,6 @@ The day of the month as a decimal number, zero-filled (range C<01> to
 C<30>). On holidays it is the holiday number, zero-filled (range C<01>
 to C<06>).
 
-=item %Ea
-
-The narrow (2-character) weekday name, or C<''> for holidays that are
-part of no week.
-
 =item %Ed
 
 The L<__on_date()|/__on_date> text for the given date.
@@ -1409,10 +1341,6 @@ The abbreviated holiday name, or C<''> for non-holidays.
 Inserts nothing, but causes the next C<%Ed> (and B<only> the next one)
 to have a C<"\n"> prefixed if there was an actual event on the date.
 
-=item %Eo
-
-The narrow (2-character) holiday name, or C<''> for non-holidays.
-
 =item %Ex
 
 Like C<'%c'>, but without the time of day, and with full names rather
@@ -1663,15 +1591,6 @@ Immediately after the flags (if any) you can specify a field width that
 overrides the default. If you explicitly specify field width, flag
 C<'-'> pads with spaces, even in numeric fields.
 
-=head2 __holiday_abbr
-
- say __holiday_abbr( 3 );
-
-Given a holiday number C<(1-6)>, this subroutine returns that holiday's
-three-letter abbreviation. If the holiday number is C<0> (i.e. the day
-is not a holiday), an empty string is returned. Otherwise, C<undef> is
-returned.
-
 =head2 __holiday_name
 
  say __holiday_name( 3 );
@@ -1691,12 +1610,12 @@ number of the holiday. Unique abbreviations of names or short names
 digits are returned unmodified. Anything unrecognized causes C<0> to be
 returned.
 
-=head2 __holiday_narrow
+=head2 __holiday_abbr
 
- say __holiday_narrow( 3 );
+ say __holiday_abbr( 3 );
 
 Given a holiday number C<(1-6)>, this subroutine returns that holiday's
-two-letter abbreviation. If the holiday number is C<0> (i.e. the day
+three-letter abbreviation. If the holiday number is C<0> (i.e. the day
 is not a holiday), an empty string is returned. Otherwise, C<undef> is
 returned.
 
@@ -1734,6 +1653,7 @@ Given a month number C<(1-12)>, this subroutine returns that month's
 three-letter abbreviation. If the month number is C<0> (i.e. a holiday),
 the empty string is returned. Otherwise C<undef> is returned.
 
+
 =head2 __on_date
 
  say __on_date( $month, $day ) // '';
@@ -1746,9 +1666,6 @@ range, C<undef> is returned.
 
 The actual text returned is from Appendix B of "Lord Of The Rings", and
 is copyright J. R. R. Tolkien, renewed by Christopher R. Tolkien et al.
-Specifically, I use the Houghton Mifflin trade paperback. I find no date
-of publication, but believe it to be the early 2000s because the cover
-illustrations appear to be movie tie-ins.
 
 =head2 __on_date_accented
 
@@ -1756,7 +1673,7 @@ illustrations appear to be movie tie-ins.
  say __on_date_accented( $month, $day ) // '';
  say __on_date( $holiday ) // '';
 
-This wrapper for L<__on_date()|/__on_date> accents those names and
+This wrapper for L<__on_date()|/__on_date()> accents those names and
 words that are accented in the text of the Lord Of The Rings. How these
 display depends on how your Perl is configured. Note that the example
 above assumes Perl 5.10 (for C<say()> and C<//>). Even without those,
@@ -1803,7 +1720,7 @@ L<http://howardhinnant.github.io/date_algorithms.html#civil_from_days>.
 
 This subroutine assumes no particular calendar, though it does assume
 the Gregorian year-length rules, which have also been adopted for the
-Shire calendar. If you feed it an honest-to-God Rata Die day (i.e. days
+Shire calendar. If you feed it am honest-to-God Rata Die day (i.e. days
 since December 31 of proleptic Gregorian year 0) you get back the
 Gregorian year and the day of that year (C<1-366>). If you feed it a
 so-called Shire Rata Die (i.e. days since 1 Yule of Shire year 0) you
@@ -1827,15 +1744,6 @@ This subroutine computes the three-letter abbreviation of a traditional
 is C<0> (i.e.  Midyear's day or the Overlithe) the empty string is
 returned. Otherwise, C<undef> is returned.
 
-=head2 __trad_weekday_narrow
-
- say 'Day 1 is ', __trad_weekday_narrow( 1 );
-
-This subroutine computes the two-letter abbreviation of a traditional
-(i.e. old-style) weekday given its number (1-7). If the weekday number
-is C<0> (i.e.  Midyear's day or the Overlithe) the empty string is
-returned. Otherwise, C<undef> is returned.
-
 =head2 __valid_date_class
 
  eval {
@@ -1852,7 +1760,7 @@ exception is thrown naming the missing methods; otherwise it returns its
 argument.
 
 If you intend to use a class that autoloads requisite methods, that
-class will need to properly override C<< UNIVERSAL->can() >>, or provide
+class will need to properly override L<can()|UNIVERSAL/can>, or provide
 forward references to autoloaded methods.
 
 This subroutine is used internally to validate the date argument to
@@ -1876,15 +1784,6 @@ given its number (1-7). If the weekday number is C<0> (i.e. Midyear's
 day or the Overlithe) the empty string is returned. Otherwise, C<undef>
 is returned.
 
-=head2 __weekday_narrow
-
- say 'Day 1 is ', __weekday_narrow( 1 );
-
-This subroutine computes the two-letter abbreviation of a weekday
-given its number (1-7). If the weekday number is C<0> (i.e. Midyear's
-day or the Overlithe) the empty string is returned. Otherwise, C<undef>
-is returned.
-
 =head2 __week_of_year
 
  say '25 Rethe is in week ', __week_of_year( 3, 25 );
@@ -1912,19 +1811,7 @@ Rata Die, as in the days since 1 Yule of Shire year 0.
 =head1 MANIFEST CONSTANTS
 
 The following manifest constants are exportable to your name space. None
-is exported by default. They can all be exported using export tag
-C<:consts>.
-
-=head2 DAY_OF_YEAR_MIDYEARS_DAY
-
-This manifest constant represents the day number of C<Midyear's day> in
-the year, i.e. C<183>.
-
-=head2 DAY_OF_YEAR_OVERLITHE
-
-This manifest constant represents the day number of C<Overlithe> in the
-year, i.e. C<184>. Be aware that day C<184> is C<Overlithe> only in a
-leap year; otherwise day C<184> is C<2 Lithe>.
+is exported by default.
 
 =head2 GREGORIAN_RATA_DIE_TO_SHIRE
 
@@ -1951,36 +1838,6 @@ L<DateTime::Fiction::JRRTolkien::Shire|DateTime::Fiction::JRRTolkien::Shire>
 version 0.21. This is after I adopted that module but before I started
 messing with the computational internals.
 
-=head3 HOLIDAY_2_YULE
-
-This manifest constant represents the holiday number of <2 Yule>, i.e.
-C<1>.
-
-=head3 HOLIDAY_1_LITHE
-
-This manifest constant represents the holiday number of <1 Lithe>, i.e.
-C<2>.
-
-=head3 HOLIDAY_MIDYEARS_DAY
-
-This manifest constant represents the holiday number of <Midyear's day>,
-i.e. C<3>.
-
-=head3 HOLIDAY_OVERLITHE
-
-This manifest constant represents the holiday number of <Overlithe>,
-i.e. C<4>.
-
-=head3 HOLIDAY_2_LITHE
-
-This manifest constant represents the holiday number of <2 Lithe>, i.e.
-C<5>.
-
-=head3 HOLIDAY_1_YULE
-
-This manifest constant represents the holiday number of <1 Yule>, i.e.
-C<6>.
-
 =head1 SEE ALSO
 
 L<Date::Tolkien::Shire|Date::Tolkien::Shire>
@@ -1990,9 +1847,7 @@ L<DateTime::Fiction::JRRTolkien::Shire|DateTime::Fiction::JRRTolkien::Shire>
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Date-Tolkien-Shire-Data>,
-L<https://github.com/trwyant/perl-Date-Tolkien-Shire-Data/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -2000,7 +1855,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2017-2022, 2025 by Thomas R. Wyant, III
+Copyright (C) 2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
